body {
    margin: 0;
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, sans-serif;
    color: #333;
    background-color: #fff;
    line-height: 1.6;
}

#body_container.cardContent {
    max-width: 1200px;
    margin: 20px auto;
    padding: 0 20px;
    box-sizing: border-box;
}

@media (max-width: 768px) {
    #body_container.cardContent {
        padding: 0 10px;
    }
}