table {
    width: 100%;
    border-collapse: collapse;
    margin-bottom: 20px;
}
th, td {
    padding: 8px;
    text-align: left;
    border: 1px solid #ddd;
}
th {
    background-color: #f2f2f2;
}
caption {
    font-weight: bold;
    padding: 8px;
}
canvas {
    max-width: 100%;
    height: auto;
}